==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/Propagator.h <==
// public abstract class soot.jimple.spark.solver.Propagator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_solver_Propagator_H_
#define _JC_soot_jimple_spark_solver_Propagator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_Propagator$sub_refs	_jc_soot_jimple_spark_solver_Propagator$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	_jc_soot_jimple_spark_solver_Propagator$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_Propagator$refs	_jc_soot_jimple_spark_solver_Propagator$refs;
typedef struct _jc_soot_jimple_spark_solver_Propagator$nonrefs	_jc_soot_jimple_spark_solver_Propagator$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_Propagator$object	_jc_soot_jimple_spark_solver_Propagator$object;

typedef const struct _jc_soot_jimple_spark_solver_Propagator$vmethods	_jc_soot_jimple_spark_solver_Propagator$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_Propagator$vtable	_jc_soot_jimple_spark_solver_Propagator$vtable;
typedef const struct _jc_soot_jimple_spark_solver_Propagator$vtype	_jc_soot_jimple_spark_solver_Propagator$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_Propagator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_solver_Propagator$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_solver_Propagator$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_Propagator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_Propagator$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_Propagator$vmethods {
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_Propagator$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_Propagator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
};

// Vtype
struct _jc_soot_jimple_spark_solver_Propagator$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_Propagator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_Propagator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_Propagator$refs {
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_Propagator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_Propagator$object {
	_jc_soot_jimple_spark_solver_Propagator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_Propagator$vtype	*vtype;
	_jc_soot_jimple_spark_solver_Propagator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_Propagator$vtype _jc_soot_jimple_spark_solver_Propagator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_Propagator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_Propagator$class_object;

#endif	/* _JC_soot_jimple_spark_solver_Propagator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/Propagator.h <==
// public abstract class soot.jimple.spark.solver.Propagator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_solver_Propagator_H_
#define _JC_soot_jimple_spark_solver_Propagator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_Propagator$sub_refs	_jc_soot_jimple_spark_solver_Propagator$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	_jc_soot_jimple_spark_solver_Propagator$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_Propagator$refs	_jc_soot_jimple_spark_solver_Propagator$refs;
typedef struct _jc_soot_jimple_spark_solver_Propagator$nonrefs	_jc_soot_jimple_spark_solver_Propagator$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_Propagator$object	_jc_soot_jimple_spark_solver_Propagator$object;

typedef const struct _jc_soot_jimple_spark_solver_Propagator$vmethods	_jc_soot_jimple_spark_solver_Propagator$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_Propagator$vtable	_jc_soot_jimple_spark_solver_Propagator$vtable;
typedef const struct _jc_soot_jimple_spark_solver_Propagator$vtype	_jc_soot_jimple_spark_solver_Propagator$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_Propagator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_solver_Propagator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_solver_Propagator$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_Propagator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_Propagator$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_Propagator$vmethods {
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_Propagator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_Propagator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
};

// Vtype
struct _jc_soot_jimple_spark_solver_Propagator$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_Propagator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_Propagator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_Propagator$refs {
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_Propagator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_Propagator$object {
	_jc_soot_jimple_spark_solver_Propagator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_Propagator$vtype	*vtype;
	_jc_soot_jimple_spark_solver_Propagator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_Propagator$vtype _jc_soot_jimple_spark_solver_Propagator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_Propagator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_Propagator$class_object;

#endif	/* _JC_soot_jimple_spark_solver_Propagator_H_ */
